@@ -39,14 +39,18 @@ extern "C" {
 namespace xmlpp
 {
 
-typedef enum {
-    XML_INTERNAL_GENERAL_ENTITY = 1,
-    XML_EXTERNAL_GENERAL_PARSED_ENTITY = 2,
-    XML_EXTERNAL_GENERAL_UNPARSED_ENTITY = 3,
-    XML_INTERNAL_PARAMETER_ENTITY = 4,
-    XML_EXTERNAL_PARAMETER_ENTITY = 5,
-    XML_INTERNAL_PREDEFINED_ENTITY = 6
-} XmlEntityType;
+// xmlpp::XmlEntityType is similar to xmlEntityType in libxml2.
+/** The valid entity types.
+ */
+enum class XmlEntityType
+{
+  INTERNAL_GENERAL = 1,
+  EXTERNAL_GENERAL_PARSED = 2,
+  EXTERNAL_GENERAL_UNPARSED = 3,
+  INTERNAL_PARAMETER = 4,
+  EXTERNAL_PARAMETER = 5,
+  INTERNAL_PREDEFINED = 6
+};
 
 //TODO: Make Document inherit from Node, when we can break ABI one day?
 //
@@ -65,7 +69,7 @@ class Document : public NonCopyable
   {
   public:
     Init();
-    ~Init();
+    ~Init() noexcept;
   };
 
   friend class SaxParser;
@@ -76,14 +80,15 @@ public:
    * @throws xmlpp::internal_error If memory allocation fails.
    */
   explicit Document(const Glib::ustring& version = "1.0");
-  
+
   /** Create a new C++ wrapper for an xmlDoc struct.
    * The created xmlpp::Document takes ownership of the xmlDoc.
    * When the Document is deleted, so is the xmlDoc and all its nodes.
    * @param doc A pointer to an xmlDoc struct. Must not be <tt>nullptr</tt>.
+   * @throws xmlpp::internal_error If @a doc is <tt>nullptr</tt>.
    */
   explicit Document(_xmlDoc* doc);
-    
+
   ~Document() override;
 
   /** @return The encoding used in the source from which the document has been loaded.
@@ -239,19 +244,24 @@ public:
    * The type of a C++ wrapper can't change. The old wrapper is deleted, and a
    * new one is created if and when it's required.)
    *
+   * Parser::set_parser_options() and DomParser::set_xinclude_options() do not
+   * affect %Document::process_xinclude().
+   *
    * @newin{2,36}
    *
    * @param generate_xinclude_nodes Generate XIncludeStart and XIncludeEnd nodes.
+   * @param fixup_base_uris Add or replace xml:base attributes in included element
+   *        nodes, if necessary to preserve the target of relative URIs.
    * @returns The number of substitutions.
    * @throws xmlpp::exception
    */
-  int process_xinclude(bool generate_xinclude_nodes = true);
+  int process_xinclude(bool generate_xinclude_nodes = true, bool fixup_base_uris = true);
 
   ///Access the underlying libxml implementation.
-  _xmlDoc* cobj();
+  _xmlDoc* cobj() noexcept;
 
   ///Access the underlying libxml implementation.
-  const _xmlDoc* cobj() const;
+  const _xmlDoc* cobj() const noexcept;
 
 protected:
   /** Retrieve an Entity.
